<?php

return [
    'Names' => [
        'af' => 'ਅਫ਼ਰੀਕੀ',
        'af_NA' => 'ਅਫ਼ਰੀਕੀ (ਨਾਮੀਬੀਆ)',
        'af_ZA' => 'ਅਫ਼ਰੀਕੀ (ਦੱਖਣੀ ਅਫਰੀਕਾ)',
        'ak' => 'ਅਕਾਨ',
        'ak_GH' => 'ਅਕਾਨ (ਘਾਨਾ)',
        'am' => 'ਅਮਹਾਰਿਕ',
        'am_ET' => 'ਅਮਹਾਰਿਕ (ਇਥੋਪੀਆ)',
        'ar' => 'ਅਰਬੀ',
        'ar_001' => 'ਅਰਬੀ (ਸੰਸਾਰ)',
        'ar_AE' => 'ਅਰਬੀ (ਸੰਯੁਕਤ ਅਰਬ ਅਮੀਰਾਤ)',
        'ar_BH' => 'ਅਰਬੀ (ਬਹਿਰੀਨ)',
        'ar_DJ' => 'ਅਰਬੀ (ਜ਼ੀਬੂਤੀ)',
        'ar_DZ' => 'ਅਰਬੀ (ਅਲਜੀਰੀਆ)',
        'ar_EG' => 'ਅਰਬੀ (ਮਿਸਰ)',
        'ar_EH' => 'ਅਰਬੀ (ਪੱਛਮੀ ਸਹਾਰਾ)',
        'ar_ER' => 'ਅਰਬੀ (ਇਰੀਟ੍ਰਿਆ)',
        'ar_IL' => 'ਅਰਬੀ (ਇਜ਼ਰਾਈਲ)',
        'ar_IQ' => 'ਅਰਬੀ (ਇਰਾਕ)',
        'ar_JO' => 'ਅਰਬੀ (ਜਾਰਡਨ)',
        'ar_KM' => 'ਅਰਬੀ (ਕੋਮੋਰੋਸ)',
        'ar_KW' => 'ਅਰਬੀ (ਕੁਵੈਤ)',
        'ar_LB' => 'ਅਰਬੀ (ਲੈਬਨਾਨ)',
        'ar_LY' => 'ਅਰਬੀ (ਲੀਬੀਆ)',
        'ar_MA' => 'ਅਰਬੀ (ਮੋਰੱਕੋ)',
        'ar_MR' => 'ਅਰਬੀ (ਮੋਰਿਟਾਨੀਆ)',
        'ar_OM' => 'ਅਰਬੀ (ਓਮਾਨ)',
        'ar_PS' => 'ਅਰਬੀ (ਫਿਲੀਸਤੀਨੀ ਇਲਾਕਾ)',
        'ar_QA' => 'ਅਰਬੀ (ਕਤਰ)',
        'ar_SA' => 'ਅਰਬੀ (ਸਾਊਦੀ ਅਰਬ)',
        'ar_SD' => 'ਅਰਬੀ (ਸੂਡਾਨ)',
        'ar_SO' => 'ਅਰਬੀ (ਸੋਮਾਲੀਆ)',
        'ar_SS' => 'ਅਰਬੀ (ਦੱਖਣ ਸੁਡਾਨ)',
        'ar_SY' => 'ਅਰਬੀ (ਸੀਰੀਆ)',
        'ar_TD' => 'ਅਰਬੀ (ਚਾਡ)',
        'ar_TN' => 'ਅਰਬੀ (ਟਿਊਨੀਸ਼ੀਆ)',
        'ar_YE' => 'ਅਰਬੀ (ਯਮਨ)',
        'as' => 'ਅਸਾਮੀ',
        'as_IN' => 'ਅਸਾਮੀ (ਭਾਰਤ)',
        'az' => 'ਅਜ਼ਰਬਾਈਜਾਨੀ',
        'az_AZ' => 'ਅਜ਼ਰਬਾਈਜਾਨੀ (ਅਜ਼ਰਬਾਈਜਾਨ)',
        'az_Cyrl' => 'ਅਜ਼ਰਬਾਈਜਾਨੀ (ਸਿਰਿਲਿਕ)',
        'az_Cyrl_AZ' => 'ਅਜ਼ਰਬਾਈਜਾਨੀ (ਸਿਰਿਲਿਕ, ਅਜ਼ਰਬਾਈਜਾਨ)',
        'az_Latn' => 'ਅਜ਼ਰਬਾਈਜਾਨੀ (ਲਾਤੀਨੀ)',
        'az_Latn_AZ' => 'ਅਜ਼ਰਬਾਈਜਾਨੀ (ਲਾਤੀਨੀ, ਅਜ਼ਰਬਾਈਜਾਨ)',
        'be' => 'ਬੇਲਾਰੂਸੀ',
        'be_BY' => 'ਬੇਲਾਰੂਸੀ (ਬੇਲਾਰੂਸ)',
        'bg' => 'ਬੁਲਗਾਰੀਆਈ',
        'bg_BG' => 'ਬੁਲਗਾਰੀਆਈ (ਬੁਲਗਾਰੀਆ)',
        'bm' => 'ਬੰਬਾਰਾ',
        'bm_ML' => 'ਬੰਬਾਰਾ (ਮਾਲੀ)',
        'bn' => 'ਬੰਗਾਲੀ',
        'bn_BD' => 'ਬੰਗਾਲੀ (ਬੰਗਲਾਦੇਸ਼)',
        'bn_IN' => 'ਬੰਗਾਲੀ (ਭਾਰਤ)',
        'bo' => 'ਤਿੱਬਤੀ',
        'bo_CN' => 'ਤਿੱਬਤੀ (ਚੀਨ)',
        'bo_IN' => 'ਤਿੱਬਤੀ (ਭਾਰਤ)',
        'br' => 'ਬਰੇਟਨ',
        'br_FR' => 'ਬਰੇਟਨ (ਫ਼ਰਾਂਸ)',
        'bs' => 'ਬੋਸਨੀਆਈ',
        'bs_BA' => 'ਬੋਸਨੀਆਈ (ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ)',
        'bs_Cyrl' => 'ਬੋਸਨੀਆਈ (ਸਿਰਿਲਿਕ)',
        'bs_Cyrl_BA' => 'ਬੋਸਨੀਆਈ (ਸਿਰਿਲਿਕ, ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ)',
        'bs_Latn' => 'ਬੋਸਨੀਆਈ (ਲਾਤੀਨੀ)',
        'bs_Latn_BA' => 'ਬੋਸਨੀਆਈ (ਲਾਤੀਨੀ, ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ)',
        'ca' => 'ਕੈਟਾਲਾਨ',
        'ca_AD' => 'ਕੈਟਾਲਾਨ (ਅੰਡੋਰਾ)',
        'ca_ES' => 'ਕੈਟਾਲਾਨ (ਸਪੇਨ)',
        'ca_FR' => 'ਕੈਟਾਲਾਨ (ਫ਼ਰਾਂਸ)',
        'ca_IT' => 'ਕੈਟਾਲਾਨ (ਇਟਲੀ)',
        'ce' => 'ਚੇਚਨ',
        'ce_RU' => 'ਚੇਚਨ (ਰੂਸ)',
        'cs' => 'ਚੈੱਕ',
        'cs_CZ' => 'ਚੈੱਕ (ਚੈਕੀਆ)',
        'cv' => 'ਚੁਵਾਸ਼',
        'cv_RU' => 'ਚੁਵਾਸ਼ (ਰੂਸ)',
        'cy' => 'ਵੈਲਸ਼',
        'cy_GB' => 'ਵੈਲਸ਼ (ਯੂਨਾਈਟਡ ਕਿੰਗਡਮ)',
        'da' => 'ਡੈਨਿਸ਼',
        'da_DK' => 'ਡੈਨਿਸ਼ (ਡੈਨਮਾਰਕ)',
        'da_GL' => 'ਡੈਨਿਸ਼ (ਗ੍ਰੀਨਲੈਂਡ)',
        'de' => 'ਜਰਮਨ',
        'de_AT' => 'ਜਰਮਨ (ਆਸਟਰੀਆ)',
        'de_BE' => 'ਜਰਮਨ (ਬੈਲਜੀਅਮ)',
        'de_CH' => 'ਜਰਮਨ (ਸਵਿਟਜ਼ਰਲੈਂਡ)',
        'de_DE' => 'ਜਰਮਨ (ਜਰਮਨੀ)',
        'de_IT' => 'ਜਰਮਨ (ਇਟਲੀ)',
        'de_LI' => 'ਜਰਮਨ (ਲਿਚੇਂਸਟਾਇਨ)',
        'de_LU' => 'ਜਰਮਨ (ਲਕਜ਼ਮਬਰਗ)',
        'dz' => 'ਜ਼ੋਂਗਖਾ',
        'dz_BT' => 'ਜ਼ੋਂਗਖਾ (ਭੂਟਾਨ)',
        'ee' => 'ਈਵਈ',
        'ee_GH' => 'ਈਵਈ (ਘਾਨਾ)',
        'ee_TG' => 'ਈਵਈ (ਟੋਗੋ)',
        'el' => 'ਯੂਨਾਨੀ',
        'el_CY' => 'ਯੂਨਾਨੀ (ਸਾਇਪ੍ਰਸ)',
        'el_GR' => 'ਯੂਨਾਨੀ (ਗ੍ਰੀਸ)',
        'en' => 'ਅੰਗਰੇਜ਼ੀ',
        'en_001' => 'ਅੰਗਰੇਜ਼ੀ (ਸੰਸਾਰ)',
        'en_150' => 'ਅੰਗਰੇਜ਼ੀ (ਯੂਰਪ)',
        'en_AE' => 'ਅੰਗਰੇਜ਼ੀ (ਸੰਯੁਕਤ ਅਰਬ ਅਮੀਰਾਤ)',
        'en_AG' => 'ਅੰਗਰੇਜ਼ੀ (ਐਂਟੀਗੁਆ ਅਤੇ ਬਾਰਬੁਡਾ)',
        'en_AI' => 'ਅੰਗਰੇਜ਼ੀ (ਅੰਗੁਇਲਾ)',
        'en_AS' => 'ਅੰਗਰੇਜ਼ੀ (ਅਮੈਰੀਕਨ ਸਮੋਆ)',
        'en_AT' => 'ਅੰਗਰੇਜ਼ੀ (ਆਸਟਰੀਆ)',
        'en_AU' => 'ਅੰਗਰੇਜ਼ੀ (ਆਸਟ੍ਰੇਲੀਆ)',
        'en_BB' => 'ਅੰਗਰੇਜ਼ੀ (ਬਾਰਬਾਡੋਸ)',
        'en_BE' => 'ਅੰਗਰੇਜ਼ੀ (ਬੈਲਜੀਅਮ)',
        'en_BI' => 'ਅੰਗਰੇਜ਼ੀ (ਬੁਰੁੰਡੀ)',
        'en_BM' => 'ਅੰਗਰੇਜ਼ੀ (ਬਰਮੂਡਾ)',
        'en_BS' => 'ਅੰਗਰੇਜ਼ੀ (ਬਹਾਮਾਸ)',
        'en_BW' => 'ਅੰਗਰੇਜ਼ੀ (ਬੋਤਸਵਾਨਾ)',
        'en_BZ' => 'ਅੰਗਰੇਜ਼ੀ (ਬੇਲੀਜ਼)',
        'en_CA' => 'ਅੰਗਰੇਜ਼ੀ (ਕੈਨੇਡਾ)',
        'en_CC' => 'ਅੰਗਰੇਜ਼ੀ (ਕੋਕੋਸ [ਕੀਲਿੰਗ] ਟਾਪੂ)',
        'en_CH' => 'ਅੰਗਰੇਜ਼ੀ (ਸਵਿਟਜ਼ਰਲੈਂਡ)',
        'en_CK' => 'ਅੰਗਰੇਜ਼ੀ (ਕੁੱਕ ਟਾਪੂ)',
        'en_CM' => 'ਅੰਗਰੇਜ਼ੀ (ਕੈਮਰੂਨ)',
        'en_CX' => 'ਅੰਗਰੇਜ਼ੀ (ਕ੍ਰਿਸਮਿਸ ਟਾਪੂ)',
        'en_CY' => 'ਅੰਗਰੇਜ਼ੀ (ਸਾਇਪ੍ਰਸ)',
        'en_DE' => 'ਅੰਗਰੇਜ਼ੀ (ਜਰਮਨੀ)',
        'en_DK' => 'ਅੰਗਰੇਜ਼ੀ (ਡੈਨਮਾਰਕ)',
        'en_DM' => 'ਅੰਗਰੇਜ਼ੀ (ਡੋਮੀਨਿਕਾ)',
        'en_ER' => 'ਅੰਗਰੇਜ਼ੀ (ਇਰੀਟ੍ਰਿਆ)',
        'en_FI' => 'ਅੰਗਰੇਜ਼ੀ (ਫਿਨਲੈਂਡ)',
        'en_FJ' => 'ਅੰਗਰੇਜ਼ੀ (ਫ਼ਿਜੀ)',
        'en_FK' => 'ਅੰਗਰੇਜ਼ੀ (ਫ਼ਾਕਲੈਂਡ ਟਾਪੂ)',
        'en_FM' => 'ਅੰਗਰੇਜ਼ੀ (ਮਾਇਕ੍ਰੋਨੇਸ਼ੀਆ)',
        'en_GB' => 'ਅੰਗਰੇਜ਼ੀ (ਯੂਨਾਈਟਡ ਕਿੰਗਡਮ)',
        'en_GD' => 'ਅੰਗਰੇਜ਼ੀ (ਗ੍ਰੇਨਾਡਾ)',
        'en_GG' => 'ਅੰਗਰੇਜ਼ੀ (ਗਰਨਜੀ)',
        'en_GH' => 'ਅੰਗਰੇਜ਼ੀ (ਘਾਨਾ)',
        'en_GI' => 'ਅੰਗਰੇਜ਼ੀ (ਜਿਬਰਾਲਟਰ)',
        'en_GM' => 'ਅੰਗਰੇਜ਼ੀ (ਗੈਂਬੀਆ)',
        'en_GU' => 'ਅੰਗਰੇਜ਼ੀ (ਗੁਆਮ)',
        'en_GY' => 'ਅੰਗਰੇਜ਼ੀ (ਗੁਯਾਨਾ)',
        'en_HK' => 'ਅੰਗਰੇਜ਼ੀ (ਹਾਂਗ ਕਾਂਗ ਐਸਏਆਰ ਚੀਨ)',
        'en_IE' => 'ਅੰਗਰੇਜ਼ੀ (ਆਇਰਲੈਂਡ)',
        'en_IL' => 'ਅੰਗਰੇਜ਼ੀ (ਇਜ਼ਰਾਈਲ)',
        'en_IM' => 'ਅੰਗਰੇਜ਼ੀ (ਆਇਲ ਆਫ ਮੈਨ)',
        'en_IN' => 'ਅੰਗਰੇਜ਼ੀ (ਭਾਰਤ)',
        'en_IO' => 'ਅੰਗਰੇਜ਼ੀ (ਬਰਤਾਨਵੀ ਹਿੰਦ ਮਹਾਂਸਾਗਰ ਖਿੱਤਾ)',
        'en_JE' => 'ਅੰਗਰੇਜ਼ੀ (ਜਰਸੀ)',
        'en_JM' => 'ਅੰਗਰੇਜ਼ੀ (ਜਮਾਇਕਾ)',
        'en_KE' => 'ਅੰਗਰੇਜ਼ੀ (ਕੀਨੀਆ)',
        'en_KI' => 'ਅੰਗਰੇਜ਼ੀ (ਕਿਰਬਾਤੀ)',
        'en_KN' => 'ਅੰਗਰੇਜ਼ੀ (ਸੇਂਟ ਕਿਟਸ ਐਂਡ ਨੇਵਿਸ)',
        'en_KY' => 'ਅੰਗਰੇਜ਼ੀ (ਕੇਮੈਨ ਟਾਪੂ)',
        'en_LC' => 'ਅੰਗਰੇਜ਼ੀ (ਸੇਂਟ ਲੂਸੀਆ)',
        'en_LR' => 'ਅੰਗਰੇਜ਼ੀ (ਲਾਈਬੀਰੀਆ)',
        'en_LS' => 'ਅੰਗਰੇਜ਼ੀ (ਲੇਸੋਥੋ)',
        'en_MG' => 'ਅੰਗਰੇਜ਼ੀ (ਮੈਡਾਗਾਸਕਰ)',
        'en_MH' => 'ਅੰਗਰੇਜ਼ੀ (ਮਾਰਸ਼ਲ ਟਾਪੂ)',
        'en_MO' => 'ਅੰਗਰੇਜ਼ੀ (ਮਕਾਉ ਐਸਏਆਰ ਚੀਨ)',
        'en_MP' => 'ਅੰਗਰੇਜ਼ੀ (ਉੱਤਰੀ ਮਾਰੀਆਨਾ ਟਾਪੂ)',
        'en_MS' => 'ਅੰਗਰੇਜ਼ੀ (ਮੋਂਟਸੇਰਾਤ)',
        'en_MT' => 'ਅੰਗਰੇਜ਼ੀ (ਮਾਲਟਾ)',
        'en_MU' => 'ਅੰਗਰੇਜ਼ੀ (ਮੌਰੀਸ਼ਸ)',
        'en_MV' => 'ਅੰਗਰੇਜ਼ੀ (ਮਾਲਦੀਵ)',
        'en_MW' => 'ਅੰਗਰੇਜ਼ੀ (ਮਲਾਵੀ)',
        'en_MY' => 'ਅੰਗਰੇਜ਼ੀ (ਮਲੇਸ਼ੀਆ)',
        'en_NA' => 'ਅੰਗਰੇਜ਼ੀ (ਨਾਮੀਬੀਆ)',
        'en_NF' => 'ਅੰਗਰੇਜ਼ੀ (ਨੋਰਫੌਕ ਟਾਪੂ)',
        'en_NG' => 'ਅੰਗਰੇਜ਼ੀ (ਨਾਈਜੀਰੀਆ)',
        'en_NL' => 'ਅੰਗਰੇਜ਼ੀ (ਨੀਦਰਲੈਂਡ)',
        'en_NR' => 'ਅੰਗਰੇਜ਼ੀ (ਨਾਉਰੂ)',
        'en_NU' => 'ਅੰਗਰੇਜ਼ੀ (ਨਿਯੂ)',
        'en_NZ' => 'ਅੰਗਰੇਜ਼ੀ (ਨਿਊਜ਼ੀਲੈਂਡ)',
        'en_PG' => 'ਅੰਗਰੇਜ਼ੀ (ਪਾਪੂਆ ਨਿਊ ਗਿਨੀ)',
        'en_PH' => 'ਅੰਗਰੇਜ਼ੀ (ਫਿਲੀਪੀਨਜ)',
        'en_PK' => 'ਅੰਗਰੇਜ਼ੀ (ਪਾਕਿਸਤਾਨ)',
        'en_PN' => 'ਅੰਗਰੇਜ਼ੀ (ਪਿਟਕੇਰਨ ਟਾਪੂ)',
        'en_PR' => 'ਅੰਗਰੇਜ਼ੀ (ਪਿਊਰਟੋ ਰਿਕੋ)',
        'en_PW' => 'ਅੰਗਰੇਜ਼ੀ (ਪਲਾਉ)',
        'en_RW' => 'ਅੰਗਰੇਜ਼ੀ (ਰਵਾਂਡਾ)',
        'en_SB' => 'ਅੰਗਰੇਜ਼ੀ (ਸੋਲੋਮਨ ਟਾਪੂ)',
        'en_SC' => 'ਅੰਗਰੇਜ਼ੀ (ਸੇਸ਼ਲਸ)',
        'en_SD' => 'ਅੰਗਰੇਜ਼ੀ (ਸੂਡਾਨ)',
        'en_SE' => 'ਅੰਗਰੇਜ਼ੀ (ਸਵੀਡਨ)',
        'en_SG' => 'ਅੰਗਰੇਜ਼ੀ (ਸਿੰਗਾਪੁਰ)',
        'en_SH' => 'ਅੰਗਰੇਜ਼ੀ (ਸੇਂਟ ਹੇਲੇਨਾ)',
        'en_SI' => 'ਅੰਗਰੇਜ਼ੀ (ਸਲੋਵੇਨੀਆ)',
        'en_SL' => 'ਅੰਗਰੇਜ਼ੀ (ਸਿਏਰਾ ਲਿਓਨ)',
        'en_SS' => 'ਅੰਗਰੇਜ਼ੀ (ਦੱਖਣ ਸੁਡਾਨ)',
        'en_SX' => 'ਅੰਗਰੇਜ਼ੀ (ਸਿੰਟ ਮਾਰਟੀਨ)',
        'en_SZ' => 'ਅੰਗਰੇਜ਼ੀ (ਇਸਵਾਤੀਨੀ)',
        'en_TC' => 'ਅੰਗਰੇਜ਼ੀ (ਟੁਰਕਸ ਅਤੇ ਕੈਕੋਸ ਟਾਪੂ)',
        'en_TK' => 'ਅੰਗਰੇਜ਼ੀ (ਟੋਕੇਲਾਉ)',
        'en_TO' => 'ਅੰਗਰੇਜ਼ੀ (ਟੌਂਗਾ)',
        'en_TT' => 'ਅੰਗਰੇਜ਼ੀ (ਟ੍ਰਿਨੀਡਾਡ ਅਤੇ ਟੋਬਾਗੋ)',
        'en_TV' => 'ਅੰਗਰੇਜ਼ੀ (ਟੁਵਾਲੂ)',
        'en_TZ' => 'ਅੰਗਰੇਜ਼ੀ (ਤਨਜ਼ਾਨੀਆ)',
        'en_UG' => 'ਅੰਗਰੇਜ਼ੀ (ਯੂਗਾਂਡਾ)',
        'en_UM' => 'ਅੰਗਰੇਜ਼ੀ (ਯੂ.ਐੱਸ. ਦੂਰ-ਦੁਰਾਡੇ ਟਾਪੂ)',
        'en_US' => 'ਅੰਗਰੇਜ਼ੀ (ਸੰਯੁਕਤ ਰਾਜ)',
        'en_VC' => 'ਅੰਗਰੇਜ਼ੀ (ਸੇਂਟ ਵਿਨਸੈਂਟ ਐਂਡ ਗ੍ਰੇਨਾਡੀਨਸ)',
        'en_VG' => 'ਅੰਗਰੇਜ਼ੀ (ਬ੍ਰਿਟਿਸ਼ ਵਰਜਿਨ ਟਾਪੂ)',
        'en_VI' => 'ਅੰਗਰੇਜ਼ੀ (ਯੂ ਐੱਸ ਵਰਜਿਨ ਟਾਪੂ)',
        'en_VU' => 'ਅੰਗਰੇਜ਼ੀ (ਵਾਨੂਆਟੂ)',
        'en_WS' => 'ਅੰਗਰੇਜ਼ੀ (ਸਾਮੋਆ)',
        'en_ZA' => 'ਅੰਗਰੇਜ਼ੀ (ਦੱਖਣੀ ਅਫਰੀਕਾ)',
        'en_ZM' => 'ਅੰਗਰੇਜ਼ੀ (ਜ਼ਾਮਬੀਆ)',
        'en_ZW' => 'ਅੰਗਰੇਜ਼ੀ (ਜ਼ਿੰਬਾਬਵੇ)',
        'eo' => 'ਇਸਪੇਰਾਂਟੋ',
        'eo_001' => 'ਇਸਪੇਰਾਂਟੋ (ਸੰਸਾਰ)',
        'es' => 'ਸਪੇਨੀ',
        'es_419' => 'ਸਪੇਨੀ (ਲਾਤੀਨੀ ਅਮਰੀਕਾ)',
        'es_AR' => 'ਸਪੇਨੀ (ਅਰਜਨਟੀਨਾ)',
        'es_BO' => 'ਸਪੇਨੀ (ਬੋਲੀਵੀਆ)',
        'es_BR' => 'ਸਪੇਨੀ (ਬ੍ਰਾਜ਼ੀਲ)',
        'es_BZ' => 'ਸਪੇਨੀ (ਬੇਲੀਜ਼)',
        'es_CL' => 'ਸਪੇਨੀ (ਚਿਲੀ)',
        'es_CO' => 'ਸਪੇਨੀ (ਕੋਲੰਬੀਆ)',
        'es_CR' => 'ਸਪੇਨੀ (ਕੋਸਟਾ ਰੀਕਾ)',
        'es_CU' => 'ਸਪੇਨੀ (ਕਿਊਬਾ)',
        'es_DO' => 'ਸਪੇਨੀ (ਡੋਮੀਨਿਕਾਈ ਗਣਰਾਜ)',
        'es_EC' => 'ਸਪੇਨੀ (ਇਕਵੇਡੋਰ)',
        'es_ES' => 'ਸਪੇਨੀ (ਸਪੇਨ)',
        'es_GQ' => 'ਸਪੇਨੀ (ਭੂ-ਖੰਡੀ ਗਿਨੀ)',
        'es_GT' => 'ਸਪੇਨੀ (ਗੁਆਟੇਮਾਲਾ)',
        'es_HN' => 'ਸਪੇਨੀ (ਹੋਂਡੁਰਸ)',
        'es_MX' => 'ਸਪੇਨੀ (ਮੈਕਸੀਕੋ)',
        'es_NI' => 'ਸਪੇਨੀ (ਨਿਕਾਰਾਗੁਆ)',
        'es_PA' => 'ਸਪੇਨੀ (ਪਨਾਮਾ)',
        'es_PE' => 'ਸਪੇਨੀ (ਪੇਰੂ)',
        'es_PH' => 'ਸਪੇਨੀ (ਫਿਲੀਪੀਨਜ)',
        'es_PR' => 'ਸਪੇਨੀ (ਪਿਊਰਟੋ ਰਿਕੋ)',
        'es_PY' => 'ਸਪੇਨੀ (ਪੈਰਾਗਵੇ)',
        'es_SV' => 'ਸਪੇਨੀ (ਅਲ ਸਲਵਾਡੋਰ)',
        'es_US' => 'ਸਪੇਨੀ (ਸੰਯੁਕਤ ਰਾਜ)',
        'es_UY' => 'ਸਪੇਨੀ (ਉਰੂਗਵੇ)',
        'es_VE' => 'ਸਪੇਨੀ (ਵੇਨੇਜ਼ੂਏਲਾ)',
        'et' => 'ਇਸਟੋਨੀਆਈ',
        'et_EE' => 'ਇਸਟੋਨੀਆਈ (ਇਸਟੋਨੀਆ)',
        'eu' => 'ਬਾਸਕ',
        'eu_ES' => 'ਬਾਸਕ (ਸਪੇਨ)',
        'fa' => 'ਫ਼ਾਰਸੀ',
        'fa_AF' => 'ਫ਼ਾਰਸੀ (ਅਫ਼ਗਾਨਿਸਤਾਨ)',
        'fa_IR' => 'ਫ਼ਾਰਸੀ (ਈਰਾਨ)',
        'ff' => 'ਫੁਲਾਹ',
        'ff_Adlm' => 'ਫੁਲਾਹ (ਅਦਲਾਮ)',
        'ff_Adlm_BF' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਬੁਰਕੀਨਾ ਫ਼ਾਸੋ)',
        'ff_Adlm_CM' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਕੈਮਰੂਨ)',
        'ff_Adlm_GH' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਘਾਨਾ)',
        'ff_Adlm_GM' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਗੈਂਬੀਆ)',
        'ff_Adlm_GN' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਗਿਨੀ)',
        'ff_Adlm_GW' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਗਿਨੀ-ਬਿਸਾਉ)',
        'ff_Adlm_LR' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਲਾਈਬੀਰੀਆ)',
        'ff_Adlm_MR' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਮੋਰਿਟਾਨੀਆ)',
        'ff_Adlm_NE' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਨਾਈਜਰ)',
        'ff_Adlm_NG' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਨਾਈਜੀਰੀਆ)',
        'ff_Adlm_SL' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਸਿਏਰਾ ਲਿਓਨ)',
        'ff_Adlm_SN' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਸੇਨੇਗਲ)',
        'ff_CM' => 'ਫੁਲਾਹ (ਕੈਮਰੂਨ)',
        'ff_GN' => 'ਫੁਲਾਹ (ਗਿਨੀ)',
        'ff_Latn' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ)',
        'ff_Latn_BF' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਬੁਰਕੀਨਾ ਫ਼ਾਸੋ)',
        'ff_Latn_CM' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਕੈਮਰੂਨ)',
        'ff_Latn_GH' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਘਾਨਾ)',
        'ff_Latn_GM' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਗੈਂਬੀਆ)',
        'ff_Latn_GN' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਗਿਨੀ)',
        'ff_Latn_GW' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਗਿਨੀ-ਬਿਸਾਉ)',
        'ff_Latn_LR' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਲਾਈਬੀਰੀਆ)',
        'ff_Latn_MR' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਮੋਰਿਟਾਨੀਆ)',
        'ff_Latn_NE' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਨਾਈਜਰ)',
        'ff_Latn_NG' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਨਾਈਜੀਰੀਆ)',
        'ff_Latn_SL' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਸਿਏਰਾ ਲਿਓਨ)',
        'ff_Latn_SN' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ, ਸੇਨੇਗਲ)',
        'ff_MR' => 'ਫੁਲਾਹ (ਮੋਰਿਟਾਨੀਆ)',
        'ff_SN' => 'ਫੁਲਾਹ (ਸੇਨੇਗਲ)',
        'fi' => 'ਫਿਨਿਸ਼',
        'fi_FI' => 'ਫਿਨਿਸ਼ (ਫਿਨਲੈਂਡ)',
        'fo' => 'ਫ਼ੇਰੋਸੇ',
        'fo_DK' => 'ਫ਼ੇਰੋਸੇ (ਡੈਨਮਾਰਕ)',
        'fo_FO' => 'ਫ਼ੇਰੋਸੇ (ਫੈਰੋ ਟਾਪੂ)',
        'fr' => 'ਫਰਾਂਸੀਸੀ',
        'fr_BE' => 'ਫਰਾਂਸੀਸੀ (ਬੈਲਜੀਅਮ)',
        'fr_BF' => 'ਫਰਾਂਸੀਸੀ (ਬੁਰਕੀਨਾ ਫ਼ਾਸੋ)',
        'fr_BI' => 'ਫਰਾਂਸੀਸੀ (ਬੁਰੁੰਡੀ)',
        'fr_BJ' => 'ਫਰਾਂਸੀਸੀ (ਬੇਨਿਨ)',
        'fr_BL' => 'ਫਰਾਂਸੀਸੀ (ਸੇਂਟ ਬਾਰਥੇਲੇਮੀ)',
        'fr_CA' => 'ਫਰਾਂਸੀਸੀ (ਕੈਨੇਡਾ)',
        'fr_CD' => 'ਫਰਾਂਸੀਸੀ (ਕਾਂਗੋ - ਕਿੰਸ਼ਾਸਾ)',
        'fr_CF' => 'ਫਰਾਂਸੀਸੀ (ਕੇਂਦਰੀ ਅਫ਼ਰੀਕੀ ਗਣਰਾਜ)',
        'fr_CG' => 'ਫਰਾਂਸੀਸੀ (ਕਾਂਗੋ - ਬ੍ਰਾਜ਼ਾਵਿਲੇ)',
        'fr_CH' => 'ਫਰਾਂਸੀਸੀ (ਸਵਿਟਜ਼ਰਲੈਂਡ)',
        'fr_CI' => 'ਫਰਾਂਸੀਸੀ (ਕੋਟ ਡੀਵੋਆਰ)',
        'fr_CM' => 'ਫਰਾਂਸੀਸੀ (ਕੈਮਰੂਨ)',
        'fr_DJ' => 'ਫਰਾਂਸੀਸੀ (ਜ਼ੀਬੂਤੀ)',
        'fr_DZ' => 'ਫਰਾਂਸੀਸੀ (ਅਲਜੀਰੀਆ)',
        'fr_FR' => 'ਫਰਾਂਸੀਸੀ (ਫ਼ਰਾਂਸ)',
        'fr_GA' => 'ਫਰਾਂਸੀਸੀ (ਗਬੋਨ)',
        'fr_GF' => 'ਫਰਾਂਸੀਸੀ (ਫਰੈਂਚ ਗੁਇਆਨਾ)',
        'fr_GN' => 'ਫਰਾਂਸੀਸੀ (ਗਿਨੀ)',
        'fr_GP' => 'ਫਰਾਂਸੀਸੀ (ਗੁਆਡੇਲੋਪ)',
        'fr_GQ' => 'ਫਰਾਂਸੀਸੀ (ਭੂ-ਖੰਡੀ ਗਿਨੀ)',
        'fr_HT' => 'ਫਰਾਂਸੀਸੀ (ਹੈਤੀ)',
        'fr_KM' => 'ਫਰਾਂਸੀਸੀ (ਕੋਮੋਰੋਸ)',
        'fr_LU' => 'ਫਰਾਂਸੀਸੀ (ਲਕਜ਼ਮਬਰਗ)',
        'fr_MA' => 'ਫਰਾਂਸੀਸੀ (ਮੋਰੱਕੋ)',
        'fr_MC' => 'ਫਰਾਂਸੀਸੀ (ਮੋਨਾਕੋ)',
        'fr_MF' => 'ਫਰਾਂਸੀਸੀ (ਸੇਂਟ ਮਾਰਟਿਨ)',
        'fr_MG' => 'ਫਰਾਂਸੀਸੀ (ਮੈਡਾਗਾਸਕਰ)',
        'fr_ML' => 'ਫਰਾਂਸੀਸੀ (ਮਾਲੀ)',
        'fr_MQ' => 'ਫਰਾਂਸੀਸੀ (ਮਾਰਟੀਨਿਕ)',
        'fr_MR' => 'ਫਰਾਂਸੀਸੀ (ਮੋਰਿਟਾਨੀਆ)',
        'fr_MU' => 'ਫਰਾਂਸੀਸੀ (ਮੌਰੀਸ਼ਸ)',
        'fr_NC' => 'ਫਰਾਂਸੀਸੀ (ਨਿਊ ਕੈਲੇਡੋਨੀਆ)',
        'fr_NE' => 'ਫਰਾਂਸੀਸੀ (ਨਾਈਜਰ)',
        'fr_PF' => 'ਫਰਾਂਸੀਸੀ (ਫਰੈਂਚ ਪੋਲੀਨੇਸ਼ੀਆ)',
        'fr_PM' => 'ਫਰਾਂਸੀਸੀ (ਸੇਂਟ ਪੀਅਰੇ ਐਂਡ ਮਿਕੇਲਨ)',
        'fr_RE' => 'ਫਰਾਂਸੀਸੀ (ਰਿਯੂਨੀਅਨ)',
        'fr_RW' => 'ਫਰਾਂਸੀਸੀ (ਰਵਾਂਡਾ)',
        'fr_SC' => 'ਫਰਾਂਸੀਸੀ (ਸੇਸ਼ਲਸ)',
        'fr_SN' => 'ਫਰਾਂਸੀਸੀ (ਸੇਨੇਗਲ)',
        'fr_SY' => 'ਫਰਾਂਸੀਸੀ (ਸੀਰੀਆ)',
        'fr_TD' => 'ਫਰਾਂਸੀਸੀ (ਚਾਡ)',
        'fr_TG' => 'ਫਰਾਂਸੀਸੀ (ਟੋਗੋ)',
        'fr_TN' => 'ਫਰਾਂਸੀਸੀ (ਟਿਊਨੀਸ਼ੀਆ)',
        'fr_VU' => 'ਫਰਾਂਸੀਸੀ (ਵਾਨੂਆਟੂ)',
        'fr_WF' => 'ਫਰਾਂਸੀਸੀ (ਵਾਲਿਸ ਅਤੇ ਫੂਟੂਨਾ)',
        'fr_YT' => 'ਫਰਾਂਸੀਸੀ (ਮਾਯੋਟੀ)',
        'fy' => 'ਪੱਛਮੀ ਫ੍ਰਿਸੀਅਨ',
        'fy_NL' => 'ਪੱਛਮੀ ਫ੍ਰਿਸੀਅਨ (ਨੀਦਰਲੈਂਡ)',
        'ga' => 'ਆਇਰਸ਼',
        'ga_GB' => 'ਆਇਰਸ਼ (ਯੂਨਾਈਟਡ ਕਿੰਗਡਮ)',
        'ga_IE' => 'ਆਇਰਸ਼ (ਆਇਰਲੈਂਡ)',
        'gd' => 'ਸਕਾਟਿਸ਼ ਗੇਲਿਕ',
        'gd_GB' => 'ਸਕਾਟਿਸ਼ ਗੇਲਿਕ (ਯੂਨਾਈਟਡ ਕਿੰਗਡਮ)',
        'gl' => 'ਗੈਲਿਸ਼ਿਅਨ',
        'gl_ES' => 'ਗੈਲਿਸ਼ਿਅਨ (ਸਪੇਨ)',
        'gu' => 'ਗੁਜਰਾਤੀ',
        'gu_IN' => 'ਗੁਜਰਾਤੀ (ਭਾਰਤ)',
        'gv' => 'ਮੈਂਕਸ',
        'gv_IM' => 'ਮੈਂਕਸ (ਆਇਲ ਆਫ ਮੈਨ)',
        'ha' => 'ਹੌਸਾ',
        'ha_GH' => 'ਹੌਸਾ (ਘਾਨਾ)',
        'ha_NE' => 'ਹੌਸਾ (ਨਾਈਜਰ)',
        'ha_NG' => 'ਹੌਸਾ (ਨਾਈਜੀਰੀਆ)',
        'he' => 'ਹਿਬਰੂ',
        'he_IL' => 'ਹਿਬਰੂ (ਇਜ਼ਰਾਈਲ)',
        'hi' => 'ਹਿੰਦੀ',
        'hi_IN' => 'ਹਿੰਦੀ (ਭਾਰਤ)',
        'hi_Latn' => 'ਹਿੰਦੀ (ਲਾਤੀਨੀ)',
        'hi_Latn_IN' => 'ਹਿੰਦੀ (ਲਾਤੀਨੀ, ਭਾਰਤ)',
        'hr' => 'ਕ੍ਰੋਏਸ਼ਿਆਈ',
        'hr_BA' => 'ਕ੍ਰੋਏਸ਼ਿਆਈ (ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ)',
        'hr_HR' => 'ਕ੍ਰੋਏਸ਼ਿਆਈ (ਕਰੋਏਸ਼ੀਆ)',
        'hu' => 'ਹੰਗਰੀਆਈ',
        'hu_HU' => 'ਹੰਗਰੀਆਈ (ਹੰਗਰੀ)',
        'hy' => 'ਅਰਮੀਨੀਆਈ',
        'hy_AM' => 'ਅਰਮੀਨੀਆਈ (ਅਰਮੀਨੀਆ)',
        'ia' => 'ਇੰਟਰਲਿੰਗੁਆ',
        'ia_001' => 'ਇੰਟਰਲਿੰਗੁਆ (ਸੰਸਾਰ)',
        'id' => 'ਇੰਡੋਨੇਸ਼ੀਆਈ',
        'id_ID' => 'ਇੰਡੋਨੇਸ਼ੀਆਈ (ਇੰਡੋਨੇਸ਼ੀਆ)',
        'ig' => 'ਇਗਬੋ',
        'ig_NG' => 'ਇਗਬੋ (ਨਾਈਜੀਰੀਆ)',
        'ii' => 'ਸਿਚੁਆਨ ਯੀ',
        'ii_CN' => 'ਸਿਚੁਆਨ ਯੀ (ਚੀਨ)',
        'is' => 'ਆਈਸਲੈਂਡਿਕ',
        'is_IS' => 'ਆਈਸਲੈਂਡਿਕ (ਆਈਸਲੈਂਡ)',
        'it' => 'ਇਤਾਲਵੀ',
        'it_CH' => 'ਇਤਾਲਵੀ (ਸਵਿਟਜ਼ਰਲੈਂਡ)',
        'it_IT' => 'ਇਤਾਲਵੀ (ਇਟਲੀ)',
        'it_SM' => 'ਇਤਾਲਵੀ (ਸੈਨ ਮਰੀਨੋ)',
        'it_VA' => 'ਇਤਾਲਵੀ (ਵੈਟੀਕਨ ਸਿਟੀ)',
        'ja' => 'ਜਪਾਨੀ',
        'ja_JP' => 'ਜਪਾਨੀ (ਜਪਾਨ)',
        'jv' => 'ਜਾਵਾਨੀਜ਼',
        'jv_ID' => 'ਜਾਵਾਨੀਜ਼ (ਇੰਡੋਨੇਸ਼ੀਆ)',
        'ka' => 'ਜਾਰਜੀਆਈ',
        'ka_GE' => 'ਜਾਰਜੀਆਈ (ਜਾਰਜੀਆ)',
        'ki' => 'ਕਿਕੂਯੂ',
        'ki_KE' => 'ਕਿਕੂਯੂ (ਕੀਨੀਆ)',
        'kk' => 'ਕਜ਼ਾਖ਼',
        'kk_KZ' => 'ਕਜ਼ਾਖ਼ (ਕਜ਼ਾਖਸਤਾਨ)',
        'kl' => 'ਕਲਾਅੱਲੀਸੁਟ',
        'kl_GL' => 'ਕਲਾਅੱਲੀਸੁਟ (ਗ੍ਰੀਨਲੈਂਡ)',
        'km' => 'ਖਮੇਰ',
        'km_KH' => 'ਖਮੇਰ (ਕੰਬੋਡੀਆ)',
        'kn' => 'ਕੰਨੜ',
        'kn_IN' => 'ਕੰਨੜ (ਭਾਰਤ)',
        'ko' => 'ਕੋਰੀਆਈ',
        'ko_KP' => 'ਕੋਰੀਆਈ (ਉੱਤਰ ਕੋਰੀਆ)',
        'ko_KR' => 'ਕੋਰੀਆਈ (ਦੱਖਣ ਕੋਰੀਆ)',
        'ks' => 'ਕਸ਼ਮੀਰੀ',
        'ks_Arab' => 'ਕਸ਼ਮੀਰੀ (ਅਰਬੀ)',
        'ks_Arab_IN' => 'ਕਸ਼ਮੀਰੀ (ਅਰਬੀ, ਭਾਰਤ)',
        'ks_Deva' => 'ਕਸ਼ਮੀਰੀ (ਦੇਵਨਾਗਰੀ)',
        'ks_Deva_IN' => 'ਕਸ਼ਮੀਰੀ (ਦੇਵਨਾਗਰੀ, ਭਾਰਤ)',
        'ks_IN' => 'ਕਸ਼ਮੀਰੀ (ਭਾਰਤ)',
        'ku' => 'ਕੁਰਦਿਸ਼',
        'ku_TR' => 'ਕੁਰਦਿਸ਼ (ਤੁਰਕੀ)',
        'kw' => 'ਕੋਰਨਿਸ਼',
        'kw_GB' => 'ਕੋਰਨਿਸ਼ (ਯੂਨਾਈਟਡ ਕਿੰਗਡਮ)',
        'ky' => 'ਕਿਰਗੀਜ਼',
        'ky_KG' => 'ਕਿਰਗੀਜ਼ (ਕਿਰਗਿਜ਼ਸਤਾਨ)',
        'lb' => 'ਲਕਜ਼ਮਬਰਗਿਸ਼',
        'lb_LU' => 'ਲਕਜ਼ਮਬਰਗਿਸ਼ (ਲਕਜ਼ਮਬਰਗ)',
        'lg' => 'ਗਾਂਡਾ',
        'lg_UG' => 'ਗਾਂਡਾ (ਯੂਗਾਂਡਾ)',
        'ln' => 'ਲਿੰਗਾਲਾ',
        'ln_AO' => 'ਲਿੰਗਾਲਾ (ਅੰਗੋਲਾ)',
        'ln_CD' => 'ਲਿੰਗਾਲਾ (ਕਾਂਗੋ - ਕਿੰਸ਼ਾਸਾ)',
        'ln_CF' => 'ਲਿੰਗਾਲਾ (ਕੇਂਦਰੀ ਅਫ਼ਰੀਕੀ ਗਣਰਾਜ)',
        'ln_CG' => 'ਲਿੰਗਾਲਾ (ਕਾਂਗੋ - ਬ੍ਰਾਜ਼ਾਵਿਲੇ)',
        'lo' => 'ਲਾਓ',
        'lo_LA' => 'ਲਾਓ (ਲਾਓਸ)',
        'lt' => 'ਲਿਥੁਆਨੀਅਨ',
        'lt_LT' => 'ਲਿਥੁਆਨੀਅਨ (ਲਿਥੁਆਨੀਆ)',
        'lu' => 'ਲੂਬਾ-ਕਾਟਾਂਗਾ',
        'lu_CD' => 'ਲੂਬਾ-ਕਾਟਾਂਗਾ (ਕਾਂਗੋ - ਕਿੰਸ਼ਾਸਾ)',
        'lv' => 'ਲਾਤੀਵੀ',
        'lv_LV' => 'ਲਾਤੀਵੀ (ਲਾਤਵੀਆ)',
        'mg' => 'ਮਾਲਾਗੈਸੀ',
        'mg_MG' => 'ਮਾਲਾਗੈਸੀ (ਮੈਡਾਗਾਸਕਰ)',
        'mi' => 'ਮਾਉਰੀ',
        'mi_NZ' => 'ਮਾਉਰੀ (ਨਿਊਜ਼ੀਲੈਂਡ)',
        'mk' => 'ਮੈਕਡੋਨੀਆਈ',
        'mk_MK' => 'ਮੈਕਡੋਨੀਆਈ (ਉੱਤਰੀ ਮੈਕਡੋਨੀਆ)',
        'ml' => 'ਮਲਿਆਲਮ',
        'ml_IN' => 'ਮਲਿਆਲਮ (ਭਾਰਤ)',
        'mn' => 'ਮੰਗੋਲੀ',
        'mn_MN' => 'ਮੰਗੋਲੀ (ਮੰਗੋਲੀਆ)',
        'mr' => 'ਮਰਾਠੀ',
        'mr_IN' => 'ਮਰਾਠੀ (ਭਾਰਤ)',
        'ms' => 'ਮਲਯ',
        'ms_BN' => 'ਮਲਯ (ਬਰੂਨੇਈ)',
        'ms_ID' => 'ਮਲਯ (ਇੰਡੋਨੇਸ਼ੀਆ)',
        'ms_MY' => 'ਮਲਯ (ਮਲੇਸ਼ੀਆ)',
        'ms_SG' => 'ਮਲਯ (ਸਿੰਗਾਪੁਰ)',
        'mt' => 'ਮਾਲਟੀਜ਼',
        'mt_MT' => 'ਮਾਲਟੀਜ਼ (ਮਾਲਟਾ)',
        'my' => 'ਬਰਮੀ',
        'my_MM' => 'ਬਰਮੀ (ਮਿਆਂਮਾਰ [ਬਰਮਾ])',
        'nb' => 'ਨਾਰਵੇਜਿਆਈ ਬੋਕਮਲ',
        'nb_NO' => 'ਨਾਰਵੇਜਿਆਈ ਬੋਕਮਲ (ਨਾਰਵੇ)',
        'nb_SJ' => 'ਨਾਰਵੇਜਿਆਈ ਬੋਕਮਲ (ਸਵਾਲਬਰਡ ਅਤੇ ਜਾਨ ਮਾਯੇਨ)',
        'nd' => 'ਉੱਤਰੀ ਨਡੇਬੇਲੇ',
        'nd_ZW' => 'ਉੱਤਰੀ ਨਡੇਬੇਲੇ (ਜ਼ਿੰਬਾਬਵੇ)',
        'ne' => 'ਨੇਪਾਲੀ',
        'ne_IN' => 'ਨੇਪਾਲੀ (ਭਾਰਤ)',
        'ne_NP' => 'ਨੇਪਾਲੀ (ਨੇਪਾਲ)',
        'nl' => 'ਡੱਚ',
        'nl_AW' => 'ਡੱਚ (ਅਰੂਬਾ)',
        'nl_BE' => 'ਡੱਚ (ਬੈਲਜੀਅਮ)',
        'nl_BQ' => 'ਡੱਚ (ਕੈਰੇਬੀਆਈ ਨੀਦਰਲੈਂਡ)',
        'nl_CW' => 'ਡੱਚ (ਕੁਰਾਕਾਓ)',
        'nl_NL' => 'ਡੱਚ (ਨੀਦਰਲੈਂਡ)',
        'nl_SR' => 'ਡੱਚ (ਸੂਰੀਨਾਮ)',
        'nl_SX' => 'ਡੱਚ (ਸਿੰਟ ਮਾਰਟੀਨ)',
        'nn' => 'ਨਾਰਵੇਜਿਆਈ ਨਿਓਨੌਰਸਕ',
        'nn_NO' => 'ਨਾਰਵੇਜਿਆਈ ਨਿਓਨੌਰਸਕ (ਨਾਰਵੇ)',
        'no' => 'ਨਾਰਵੇਜਿਆਈ',
        'no_NO' => 'ਨਾਰਵੇਜਿਆਈ (ਨਾਰਵੇ)',
        'om' => 'ਓਰੋਮੋ',
        'om_ET' => 'ਓਰੋਮੋ (ਇਥੋਪੀਆ)',
        'om_KE' => 'ਓਰੋਮੋ (ਕੀਨੀਆ)',
        'or' => 'ਉੜੀਆ',
        'or_IN' => 'ਉੜੀਆ (ਭਾਰਤ)',
        'os' => 'ਓਸੈਟਿਕ',
        'os_GE' => 'ਓਸੈਟਿਕ (ਜਾਰਜੀਆ)',
        'os_RU' => 'ਓਸੈਟਿਕ (ਰੂਸ)',
        'pa' => 'ਪੰਜਾਬੀ',
        'pa_Arab' => 'ਪੰਜਾਬੀ (ਅਰਬੀ)',
        'pa_Arab_PK' => 'ਪੰਜਾਬੀ (ਅਰਬੀ, ਪਾਕਿਸਤਾਨ)',
        'pa_Guru' => 'ਪੰਜਾਬੀ (ਗੁਰਮੁਖੀ)',
        'pa_Guru_IN' => 'ਪੰਜਾਬੀ (ਗੁਰਮੁਖੀ, ਭਾਰਤ)',
        'pa_IN' => 'ਪੰਜਾਬੀ (ਭਾਰਤ)',
        'pa_PK' => 'ਪੰਜਾਬੀ (ਪਾਕਿਸਤਾਨ)',
        'pl' => 'ਪੋਲੈਂਡੀ',
        'pl_PL' => 'ਪੋਲੈਂਡੀ (ਪੋਲੈਂਡ)',
        'ps' => 'ਪਸ਼ਤੋ',
        'ps_AF' => 'ਪਸ਼ਤੋ (ਅਫ਼ਗਾਨਿਸਤਾਨ)',
        'ps_PK' => 'ਪਸ਼ਤੋ (ਪਾਕਿਸਤਾਨ)',
        'pt' => 'ਪੁਰਤਗਾਲੀ',
        'pt_AO' => 'ਪੁਰਤਗਾਲੀ (ਅੰਗੋਲਾ)',
        'pt_BR' => 'ਪੁਰਤਗਾਲੀ (ਬ੍ਰਾਜ਼ੀਲ)',
        'pt_CH' => 'ਪੁਰਤਗਾਲੀ (ਸਵਿਟਜ਼ਰਲੈਂਡ)',
        'pt_CV' => 'ਪੁਰਤਗਾਲੀ (ਕੇਪ ਵਰਡੇ)',
        'pt_GQ' => 'ਪੁਰਤਗਾਲੀ (ਭੂ-ਖੰਡੀ ਗਿਨੀ)',
        'pt_GW' => 'ਪੁਰਤਗਾਲੀ (ਗਿਨੀ-ਬਿਸਾਉ)',
        'pt_LU' => 'ਪੁਰਤਗਾਲੀ (ਲਕਜ਼ਮਬਰਗ)',
        'pt_MO' => 'ਪੁਰਤਗਾਲੀ (ਮਕਾਉ ਐਸਏਆਰ ਚੀਨ)',
        'pt_MZ' => 'ਪੁਰਤਗਾਲੀ (ਮੋਜ਼ਾਮਬੀਕ)',
        'pt_PT' => 'ਪੁਰਤਗਾਲੀ (ਪੁਰਤਗਾਲ)',
        'pt_ST' => 'ਪੁਰਤਗਾਲੀ (ਸਾਓ ਟੋਮ ਅਤੇ ਪ੍ਰਿੰਸੀਪੇ)',
        'pt_TL' => 'ਪੁਰਤਗਾਲੀ (ਤਿਮੋਰ-ਲੇਸਤੇ)',
        'qu' => 'ਕਕੇਸ਼ੁਆ',
        'qu_BO' => 'ਕਕੇਸ਼ੁਆ (ਬੋਲੀਵੀਆ)',
        'qu_EC' => 'ਕਕੇਸ਼ੁਆ (ਇਕਵੇਡੋਰ)',
        'qu_PE' => 'ਕਕੇਸ਼ੁਆ (ਪੇਰੂ)',
        'rm' => 'ਰੋਮਾਂਸ਼',
        'rm_CH' => 'ਰੋਮਾਂਸ਼ (ਸਵਿਟਜ਼ਰਲੈਂਡ)',
        'rn' => 'ਰੁੰਡੀ',
        'rn_BI' => 'ਰੁੰਡੀ (ਬੁਰੁੰਡੀ)',
        'ro' => 'ਰੋਮਾਨੀਆਈ',
        'ro_MD' => 'ਰੋਮਾਨੀਆਈ (ਮੋਲਡੋਵਾ)',
        'ro_RO' => 'ਰੋਮਾਨੀਆਈ (ਰੋਮਾਨੀਆ)',
        'ru' => 'ਰੂਸੀ',
        'ru_BY' => 'ਰੂਸੀ (ਬੇਲਾਰੂਸ)',
        'ru_KG' => 'ਰੂਸੀ (ਕਿਰਗਿਜ਼ਸਤਾਨ)',
        'ru_KZ' => 'ਰੂਸੀ (ਕਜ਼ਾਖਸਤਾਨ)',
        'ru_MD' => 'ਰੂਸੀ (ਮੋਲਡੋਵਾ)',
        'ru_RU' => 'ਰੂਸੀ (ਰੂਸ)',
        'ru_UA' => 'ਰੂਸੀ (ਯੂਕਰੇਨ)',
        'rw' => 'ਕਿਨਿਆਰਵਾਂਡਾ',
        'rw_RW' => 'ਕਿਨਿਆਰਵਾਂਡਾ (ਰਵਾਂਡਾ)',
        'sa' => 'ਸੰਸਕ੍ਰਿਤ',
        'sa_IN' => 'ਸੰਸਕ੍ਰਿਤ (ਭਾਰਤ)',
        'sc' => 'ਸਾਰਡੀਨੀਆਈ',
        'sc_IT' => 'ਸਾਰਡੀਨੀਆਈ (ਇਟਲੀ)',
        'sd' => 'ਸਿੰਧੀ',
        'sd_Arab' => 'ਸਿੰਧੀ (ਅਰਬੀ)',
        'sd_Arab_PK' => 'ਸਿੰਧੀ (ਅਰਬੀ, ਪਾਕਿਸਤਾਨ)',
        'sd_Deva' => 'ਸਿੰਧੀ (ਦੇਵਨਾਗਰੀ)',
        'sd_Deva_IN' => 'ਸਿੰਧੀ (ਦੇਵਨਾਗਰੀ, ਭਾਰਤ)',
        'sd_IN' => 'ਸਿੰਧੀ (ਭਾਰਤ)',
        'sd_PK' => 'ਸਿੰਧੀ (ਪਾਕਿਸਤਾਨ)',
        'se' => 'ਉੱਤਰੀ ਸਾਮੀ',
        'se_FI' => 'ਉੱਤਰੀ ਸਾਮੀ (ਫਿਨਲੈਂਡ)',
        'se_NO' => 'ਉੱਤਰੀ ਸਾਮੀ (ਨਾਰਵੇ)',
        'se_SE' => 'ਉੱਤਰੀ ਸਾਮੀ (ਸਵੀਡਨ)',
        'sg' => 'ਸਾਂਗੋ',
        'sg_CF' => 'ਸਾਂਗੋ (ਕੇਂਦਰੀ ਅਫ਼ਰੀਕੀ ਗਣਰਾਜ)',
        'si' => 'ਸਿੰਹਾਲਾ',
        'si_LK' => 'ਸਿੰਹਾਲਾ (ਸ੍ਰੀ ਲੰਕਾ)',
        'sk' => 'ਸਲੋਵਾਕ',
        'sk_SK' => 'ਸਲੋਵਾਕ (ਸਲੋਵਾਕੀਆ)',
        'sl' => 'ਸਲੋਵੇਨੀਆਈ',
        'sl_SI' => 'ਸਲੋਵੇਨੀਆਈ (ਸਲੋਵੇਨੀਆ)',
        'sn' => 'ਸ਼ੋਨਾ',
        'sn_ZW' => 'ਸ਼ੋਨਾ (ਜ਼ਿੰਬਾਬਵੇ)',
        'so' => 'ਸੋਮਾਲੀ',
        'so_DJ' => 'ਸੋਮਾਲੀ (ਜ਼ੀਬੂਤੀ)',
        'so_ET' => 'ਸੋਮਾਲੀ (ਇਥੋਪੀਆ)',
        'so_KE' => 'ਸੋਮਾਲੀ (ਕੀਨੀਆ)',
        'so_SO' => 'ਸੋਮਾਲੀ (ਸੋਮਾਲੀਆ)',
        'sq' => 'ਅਲਬਾਨੀਆਈ',
        'sq_AL' => 'ਅਲਬਾਨੀਆਈ (ਅਲਬਾਨੀਆ)',
        'sq_MK' => 'ਅਲਬਾਨੀਆਈ (ਉੱਤਰੀ ਮੈਕਡੋਨੀਆ)',
        'sr' => 'ਸਰਬੀਆਈ',
        'sr_BA' => 'ਸਰਬੀਆਈ (ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ)',
        'sr_Cyrl' => 'ਸਰਬੀਆਈ (ਸਿਰਿਲਿਕ)',
        'sr_Cyrl_BA' => 'ਸਰਬੀਆਈ (ਸਿਰਿਲਿਕ, ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ)',
        'sr_Cyrl_ME' => 'ਸਰਬੀਆਈ (ਸਿਰਿਲਿਕ, ਮੋਂਟੇਨੇਗਰੋ)',
        'sr_Cyrl_RS' => 'ਸਰਬੀਆਈ (ਸਿਰਿਲਿਕ, ਸਰਬੀਆ)',
        'sr_Latn' => 'ਸਰਬੀਆਈ (ਲਾਤੀਨੀ)',
        'sr_Latn_BA' => 'ਸਰਬੀਆਈ (ਲਾਤੀਨੀ, ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ)',
        'sr_Latn_ME' => 'ਸਰਬੀਆਈ (ਲਾਤੀਨੀ, ਮੋਂਟੇਨੇਗਰੋ)',
        'sr_Latn_RS' => 'ਸਰਬੀਆਈ (ਲਾਤੀਨੀ, ਸਰਬੀਆ)',
        'sr_ME' => 'ਸਰਬੀਆਈ (ਮੋਂਟੇਨੇਗਰੋ)',
        'sr_RS' => 'ਸਰਬੀਆਈ (ਸਰਬੀਆ)',
        'su' => 'ਸੂੰਡਾਨੀ',
        'su_ID' => 'ਸੂੰਡਾਨੀ (ਇੰਡੋਨੇਸ਼ੀਆ)',
        'su_Latn' => 'ਸੂੰਡਾਨੀ (ਲਾਤੀਨੀ)',
        'su_Latn_ID' => 'ਸੂੰਡਾਨੀ (ਲਾਤੀਨੀ, ਇੰਡੋਨੇਸ਼ੀਆ)',
        'sv' => 'ਸਵੀਡਿਸ਼',
        'sv_AX' => 'ਸਵੀਡਿਸ਼ (ਅਲੈਂਡ ਟਾਪੂ)',
        'sv_FI' => 'ਸਵੀਡਿਸ਼ (ਫਿਨਲੈਂਡ)',
        'sv_SE' => 'ਸਵੀਡਿਸ਼ (ਸਵੀਡਨ)',
        'sw' => 'ਸਵਾਹਿਲੀ',
        'sw_CD' => 'ਸਵਾਹਿਲੀ (ਕਾਂਗੋ - ਕਿੰਸ਼ਾਸਾ)',
        'sw_KE' => 'ਸਵਾਹਿਲੀ (ਕੀਨੀਆ)',
        'sw_TZ' => 'ਸਵਾਹਿਲੀ (ਤਨਜ਼ਾਨੀਆ)',
        'sw_UG' => 'ਸਵਾਹਿਲੀ (ਯੂਗਾਂਡਾ)',
        'ta' => 'ਤਮਿਲ',
        'ta_IN' => 'ਤਮਿਲ (ਭਾਰਤ)',
        'ta_LK' => 'ਤਮਿਲ (ਸ੍ਰੀ ਲੰਕਾ)',
        'ta_MY' => 'ਤਮਿਲ (ਮਲੇਸ਼ੀਆ)',
        'ta_SG' => 'ਤਮਿਲ (ਸਿੰਗਾਪੁਰ)',
        'te' => 'ਤੇਲਗੂ',
        'te_IN' => 'ਤੇਲਗੂ (ਭਾਰਤ)',
        'tg' => 'ਤਾਜਿਕ',
        'tg_TJ' => 'ਤਾਜਿਕ (ਤਾਜਿਕਿਸਤਾਨ)',
        'th' => 'ਥਾਈ',
        'th_TH' => 'ਥਾਈ (ਥਾਈਲੈਂਡ)',
        'ti' => 'ਤਿਗ੍ਰੀਨਿਆ',
        'ti_ER' => 'ਤਿਗ੍ਰੀਨਿਆ (ਇਰੀਟ੍ਰਿਆ)',
        'ti_ET' => 'ਤਿਗ੍ਰੀਨਿਆ (ਇਥੋਪੀਆ)',
        'tk' => 'ਤੁਰਕਮੇਨ',
        'tk_TM' => 'ਤੁਰਕਮੇਨ (ਤੁਰਕਮੇਨਿਸਤਾਨ)',
        'to' => 'ਟੌਂਗਨ',
        'to_TO' => 'ਟੌਂਗਨ (ਟੌਂਗਾ)',
        'tr' => 'ਤੁਰਕੀ',
        'tr_CY' => 'ਤੁਰਕੀ (ਸਾਇਪ੍ਰਸ)',
        'tr_TR' => 'ਤੁਰਕੀ (ਤੁਰਕੀ)',
        'tt' => 'ਤਤਾਰ',
        'tt_RU' => 'ਤਤਾਰ (ਰੂਸ)',
        'ug' => 'ਉਇਗੁਰ',
        'ug_CN' => 'ਉਇਗੁਰ (ਚੀਨ)',
        'uk' => 'ਯੂਕਰੇਨੀਆਈ',
        'uk_UA' => 'ਯੂਕਰੇਨੀਆਈ (ਯੂਕਰੇਨ)',
        'ur' => 'ਉਰਦੂ',
        'ur_IN' => 'ਉਰਦੂ (ਭਾਰਤ)',
        'ur_PK' => 'ਉਰਦੂ (ਪਾਕਿਸਤਾਨ)',
        'uz' => 'ਉਜ਼ਬੇਕ',
        'uz_AF' => 'ਉਜ਼ਬੇਕ (ਅਫ਼ਗਾਨਿਸਤਾਨ)',
        'uz_Arab' => 'ਉਜ਼ਬੇਕ (ਅਰਬੀ)',
        'uz_Arab_AF' => 'ਉਜ਼ਬੇਕ (ਅਰਬੀ, ਅਫ਼ਗਾਨਿਸਤਾਨ)',
        'uz_Cyrl' => 'ਉਜ਼ਬੇਕ (ਸਿਰਿਲਿਕ)',
        'uz_Cyrl_UZ' => 'ਉਜ਼ਬੇਕ (ਸਿਰਿਲਿਕ, ਉਜ਼ਬੇਕਿਸਤਾਨ)',
        'uz_Latn' => 'ਉਜ਼ਬੇਕ (ਲਾਤੀਨੀ)',
        'uz_Latn_UZ' => 'ਉਜ਼ਬੇਕ (ਲਾਤੀਨੀ, ਉਜ਼ਬੇਕਿਸਤਾਨ)',
        'uz_UZ' => 'ਉਜ਼ਬੇਕ (ਉਜ਼ਬੇਕਿਸਤਾਨ)',
        'vi' => 'ਵੀਅਤਨਾਮੀ',
        'vi_VN' => 'ਵੀਅਤਨਾਮੀ (ਵੀਅਤਨਾਮ)',
        'wo' => 'ਵੋਲੋਫ',
        'wo_SN' => 'ਵੋਲੋਫ (ਸੇਨੇਗਲ)',
        'xh' => 'ਖੋਸਾ',
        'xh_ZA' => 'ਖੋਸਾ (ਦੱਖਣੀ ਅਫਰੀਕਾ)',
        'yi' => 'ਯਿਦਿਸ਼',
        'yi_001' => 'ਯਿਦਿਸ਼ (ਸੰਸਾਰ)',
        'yo' => 'ਯੋਰੂਬਾ',
        'yo_BJ' => 'ਯੋਰੂਬਾ (ਬੇਨਿਨ)',
        'yo_NG' => 'ਯੋਰੂਬਾ (ਨਾਈਜੀਰੀਆ)',
        'zh' => 'ਚੀਨੀ',
        'zh_CN' => 'ਚੀਨੀ (ਚੀਨ)',
        'zh_HK' => 'ਚੀਨੀ (ਹਾਂਗ ਕਾਂਗ ਐਸਏਆਰ ਚੀਨ)',
        'zh_Hans' => 'ਚੀਨੀ (ਸਰਲ)',
        'zh_Hans_CN' => 'ਚੀਨੀ (ਸਰਲ, ਚੀਨ)',
        'zh_Hans_HK' => 'ਚੀਨੀ (ਸਰਲ, ਹਾਂਗ ਕਾਂਗ ਐਸਏਆਰ ਚੀਨ)',
        'zh_Hans_MO' => 'ਚੀਨੀ (ਸਰਲ, ਮਕਾਉ ਐਸਏਆਰ ਚੀਨ)',
        'zh_Hans_SG' => 'ਚੀਨੀ (ਸਰਲ, ਸਿੰਗਾਪੁਰ)',
        'zh_Hant' => 'ਚੀਨੀ (ਰਵਾਇਤੀ)',
        'zh_Hant_HK' => 'ਚੀਨੀ (ਰਵਾਇਤੀ, ਹਾਂਗ ਕਾਂਗ ਐਸਏਆਰ ਚੀਨ)',
        'zh_Hant_MO' => 'ਚੀਨੀ (ਰਵਾਇਤੀ, ਮਕਾਉ ਐਸਏਆਰ ਚੀਨ)',
        'zh_Hant_TW' => 'ਚੀਨੀ (ਰਵਾਇਤੀ, ਤਾਇਵਾਨ)',
        'zh_MO' => 'ਚੀਨੀ (ਮਕਾਉ ਐਸਏਆਰ ਚੀਨ)',
        'zh_SG' => 'ਚੀਨੀ (ਸਿੰਗਾਪੁਰ)',
        'zh_TW' => 'ਚੀਨੀ (ਤਾਇਵਾਨ)',
        'zu' => 'ਜ਼ੁਲੂ',
        'zu_ZA' => 'ਜ਼ੁਲੂ (ਦੱਖਣੀ ਅਫਰੀਕਾ)',
    ],
];
